@@ -128,10 +128,15 @@ def get_branch_name_from_issue(issue_id: str) -> [str]:
 def create_branch(branch_name, push=False, target: Path = Path.cwd(), source_branch='develop'):
     try:
         repo = Repo(target)
-        #  check if dirty
+
+        stashed_changes = False
+
+        #  if dirty stash all changes and apply them on the new branch
         if repo.is_dirty():
-            click.secho("Current working dir not clean, please commit or stash your changes first", fg='red')
-            raise Exception("Current working dir not clean, please commit or stash your changes first")
+            repo.git.execute(['git', 'stash'])
+            stashed_changes = True
+            # click.secho("Current working dir not clean, please commit or stash your changes first", fg='red')
+            # raise Exception("Current working dir not clean, please commit or stash your changes first")
 
         # check if develop exists otherwise switch to master otherwise switch to main
         for branch in [source_branch, 'master', 'main']:
@@ -198,6 +203,10 @@ def create_branch(branch_name, push=False, target: Path = Path.cwd(), source_bra
             click.secho(''.ljust(len(upstream_branch_command), '#'))
             click.echo(f' > {upstream_branch_command}')
             click.secho(''.ljust(len(branch_name), '#'))
+
+        if stashed_changes:
+            repo.git.execute(['git', 'stash', 'pop'])
+
         click.secho('Switching to new branch. Good luck!', fg='green')
 
     except InvalidGitRepositoryError as err:
